import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:logger/logger.dart';
import 'package:xpay/xpay.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  Future<void> initPlatformState() async {
    String platformVersion;

    try {
      platformVersion =
          await Xpay.getAliPayVersion ?? 'Unknown platform version';
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              ElevatedButton(
                  onPressed: () async {
                    var version = await Xpay.getAliPayVersion;
                    Logger().d(version);
                  },
                  child: Text('Running on: $_platformVersion\n')),
              ElevatedButton(
                  onPressed: () async {
                    //order 需要从服务器获取
                    var result = await Xpay.aliPay('order');
                    Logger().d(result);
                  },
                  child: const Text('aliPay')),
              ElevatedButton(
                  onPressed: () async {
                    var result = await Xpay.aliIsAliPayInstalled();
                    Logger().d(result);
                  },
                  child: const Text('isInstallAliPay'))
            ],
          ),
        ),
      ),
    );
  }
}
